@@ -8,10 +8,15 @@ from urllib.parse import urlencode
 from bravado.requests_client import Authenticator
 
 
-QUOTATION_PARAMS = ['uuids', 'txids', 'identifiers']
+EXCHANGE_PARAMS  = ['uuids', 'txids', 'identifiers', 'states']
+QUOTATION_PARAMS = ['uuids', 'txids', 'identifiers',]
+QUERY_PARAMS     = set(EXCHANGE_PARAMS)
 MAPPER           = 'swg_mapper.json'
 
 
+QUERY_PARAMS.update(QUOTATION_PARAMS)
+
+
 class APIKeyAuthenticator(Authenticator):
 
     def __init__(
@@ -68,15 +73,15 @@ class APIKeyAuthenticator(Authenticator):
         query = urlencode({
             k: v
             for k, v in params.items()
-            if k not in QUOTATION_PARAMS
+            if k not in QUERY_PARAMS
         })
-        for quotation in QUOTATION_PARAMS:
-            if params.get(quotation):
-                param = params.pop(quotation)
-                params[f"{quotation}[]"] = param
+        for query_param in QUERY_PARAMS:
+            if params.get(query_param):
+                param = params.pop(query_param)
+                params[f"{query_param}[]"] = param
                 query_params = '&'.join([
-                    f"{quotation}[]={q}"
-                    for q in quotation
+                    f"{query_param}[]={q}"
+                    for q in query_param
                 ])
                 query = f"{query}&{query_params}" if query else query_params
         return query
